import styled from 'styled-components';

export const PageWrapper = styled('div')<{
  width: number;
  height: number;
  rotation?: number;
}>`
  direction: ltr;
  position: relative;
  overflow: visible;
  background-clip: content-box;
  display: inline-block;
  margin: 25px auto;

  width: ${(props) => props.width}px;
  height: ${(props) => props.height}px;
  transform: rotate(${(props) => props.rotation}deg);
  background-color: white;

  &:first-of-type {
    margin-top: 40px;
  }
`;

export const PdfCanvas = styled.canvas`
  margin: 0;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
`;

export const TextLayer = styled.div<{ disabledSelect: boolean }>`
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  margin: auto;
  overflow: hidden;
  opacity: 0.3;
  line-height: 1;
  pointer-events: ${(props) => (props.disabledSelect ? 'none' : 'auto')};

  & > span {
    color: transparent;
    position: absolute;
    white-space: pre;
    cursor: text;
    transform-origin: 0% 0%;

    ::selection {
      color: transparent;
      background: rgba(0, 0, 255, 1);
    }

    ::after {
      content: ' ';
    }
  }
`;

export const AnnotationLayer = styled.div`
  position: absolute;
  left: 0;
  top: 0;
`;

export const WatermarkLayer = styled.div`
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  display: flex;
  justify-content: center;
  align-items: center;
  pointer-events: none;
`;

export const Inner = styled.div`
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
  font-size: 1.5rem;
`;

export const Canvas = styled.svg`
  display: block;
  position: absolute;
  top: 0;
  left: 0;
`;
